@@ -30,7 +30,7 @@ use crate::commands::project::{
 };
 use crate::commands::{ExitStatus, OutputWriter, diagnostics};
 use crate::printer::Printer;
-use crate::settings::ResolverSettings;
+use crate::settings::{LockCheck, ResolverSettings};
 
 #[derive(Debug, Clone)]
 #[allow(clippy::large_enum_variant)]
@@ -64,8 +64,8 @@ pub(crate) async fn export(
     output_file: Option<PathBuf>,
     extras: ExtrasSpecification,
     groups: DependencyGroups,
-    editable: EditableMode,
-    locked: bool,
+    editable: Option<EditableMode>,
+    lock_check: LockCheck,
     frozen: bool,
     include_annotations: bool,
     include_header: bool,
@@ -172,8 +172,8 @@ pub(crate) async fn export(
     // Determine the lock mode.
     let mode = if frozen {
         LockMode::Frozen
-    } else if locked {
-        LockMode::Locked(interpreter.as_ref().unwrap())
+    } else if let LockCheck::Enabled(lock_check) = lock_check {
+        LockMode::Locked(interpreter.as_ref().unwrap(), lock_check)
     } else if matches!(target, ExportTarget::Script(_))
         && !LockTarget::from(&target).lock_path().is_file()
     {
